# Tutorials

AutoRA consists of modules specific to different stages of empirical research as well as supporting utilities and ancillary research procedures. The following tutorials demonstrate how to use these various components, both independently and in combination for closed-loop scientific discovery. 

If you have questions about these tutorials or would otherwise like to discuss use of AutoRA, feel free to start or join a discussion in the [Using AutoRA](https://github.com/orgs/AutoResearch/discussions/categories/using-autora) section of the AutoRA forum.
